# librapythonpro
Modulo para exemplificar construçao de projetos python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de codigo aberto

Link do curso [Python Pro](https://plataforma.dev.pro.br/)

[![Build Status](https://travis-ci.com/Ioboss/librapythonpro.svg?branch=main)](https://travis-ci.com/Ioboss/librapythonpro)
[![Updates](https://pyup.io/repos/github/Ioboss/librapythonpro/shield.svg)](https://pyup.io/repos/github/Ioboss/librapythonpro/)
[![Python 3](https://pyup.io/repos/github/Ioboss/librapythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Ioboss/librapythonpro/)

Suportado Python 3

Para instalar:

''' Console
python3 -m venv .venv

source .venv/bin/activate

pip install -r requirements-dev.txt
'''

Para conferir qualidade de codigo:

''' Console

flake8
'''

Topicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
